# Cursor rules — Aut-O standard + project variability

| Type | File(s) | Source |
|------|--------|--------|
| **Aut-O standard** | `aut-o-core.mdc`, `session-protocol.mdc`, `precursor-workflow.mdc`, `orchestration.mdc`, `deferred-items.mdc` (optional) | aut-o.com/sync/templates/cursor-rules/ (SSOT) |
| **Project (variability)** | `project-context.mdc`, `knowledge-sync.mdc`, `sync-completeness.mdc`, `architecture-decisions.mdc`, `coding-standards.mdc`, `github-access.mdc`, `evolution-mindset.mdc`, `debate-protocol.mdc` | LLMHosts.com-specific |

Sync only the Aut-O standard files from Aut-O; do not overwrite project files.
